#

# This script is for the August 18, 2020 ROSES course. The script is executable, but it is meant to follow along; cut and paste commands into a UNIX terminal window.

# Much of this instruction is in the manual ~bayesloc/doc/bayesloc.pdf, and I suggest looking at the manual first.

# Let's locate 1 event
#   Start by looking at the configuration file. Open bayesloc_1ev_short.cfg in your favorite text editor
#   I want you to see how simple the input can be.
#vi bayesloc_1ev_short.cfg
#   Run bayesloc

../../Bayesloc/BayesLoc2-beta/bin/bayesloc bayesloc_1ev_short.cfg

#   change directory to output 

cd output

#   What are the files?
#   1) origins_ned_stats.out lists the event locations. We will open this file and take a look
#   2) atep_phase_factors_stats.out lists the phase precision (1/variance) and uncertainty for each phase. This shows you which phases are precisely picked (high precision).
#   3) Bayesloc always outputs the full bayesloc configuration file that was used and the data that were used for location
#      bayesloc_used.out  You will see that this file is much more extensive than the simple input file we use. Bayesloc assessed that you locate 1 event and turned off most features because they are unresolved. See bayesloc_annotated_full.cfg in the ROSES home directory for an commented bayesloc input file
#      arrivals.out
#      stations.out
#      I included a code to plot error ellipses using GoogleEarth, and the script plotLocsKML.csh runs the code, and the script plotLocsKML.csh runs the code

../plotLocsKML.csh
mv epiPlot.kml singleEvent.kml
open singleEvent.kml

# This event is an explosion and we know exactly where it occurred

open ../knownLocation.kml

# Why is the location biased? 
# Let's rerun bayesloc and output the MCMCsamplesi

cd ..
../../Bayesloc/BayesLoc2-beta/bin/bayesloc bayesloc_1ev_samples.cfg

# Then look at the samples

cd output_1event
../plotplotSamples.csh
open MCMC_samples.kml

# It doesnt looks like a non-Gaussian posteriori distribution is the problem
# In this case location bias is cause by biased travel time predictions.
cd ..
#########################################################################

# Now simultaneously locate 5 events with travel-time corrections on. 

../../Bayesloc/BayesLoc2-beta/bin/bayesloc bayesloc_5ev_short.cfg
cd output_5events
../plotLocsKML.csh
mv epiPlot.kml fiveEvent.kml
open fiveEvent.kml

# Epicenter bias has been removed. 
# tte_phase_dist_scales_stats.out shows that the slowness of each phase is adjusted
# The adjustments are in slowness, and the Pn adjustment equates to changing the ak135 
# Pn velocity from 8.05 km/s to 8.01 km/s - 0.038 km/s ( 0.038=1/(0.235 s/deg) / 111.2 deg/km
# So Pn velocity is reduced. Typical Pn velicty for the Basin and Range is ~7.95 km/s. So the correction is in the right direction.
# There is also a tte_phase_shifts_stats.out file that shows the travel time shifts. 
# Look at the bayesloc_used.cfg to see that prior constraints were put on the shifts because this data set doesn't have enough informatoin to constrain these parameters
cd ..
#########################################################################
# Now simultaneously locate 74 events with even more travel time corrections on

../../Bayesloc/BayesLoc2-beta/bin/bayesloc bayesloc_74ev_short.cfg

cd output_74events
../plotLocsKML.csh
mv epiPlot.kml 74_event.kml
open 74_event.kml

# the ellipse is smaller, but the bias appears to be large. The true location is on the edge of the ellipse
# Why? More data is used to constrain the bayesloc parameters, but most of the data are from far away, which degrades precision
# Let's look at atep_phase_factors_stats.out and ../output_5events/atep_phase_factors_stats.out
cat atep_phase_factors_stats.out 
cat ../output_5events/atep_phase_factors_stats.out
#Pn is slightly more precise for the 74 event case, but precisions of the secondary phases are significantly degraded

cd ..
#########################################################################
# Last test case: priors
# open  origin_prior.dat
# use a prior on one events

open origin_prior.kml

../../Bayesloc/BayesLoc2-beta/bin/bayesloc bayesloc_74ev_prior.cfg
cd output_74events_prior
../plotLocsKML.csh
mv epiPlot.kml 74_event_prior.kml
open 74_event_prior.kml

grep 609251 ../output_74events/origins_ned_stats.out
grep 609251 origins_ned_stats.out


# The location is about the same, but the depth is better characterized.  
# Further studies: compare results using differing bayesloc parameters to known locations


####################################################

# Look at the configureation files in the Annotated_cfg directory. 
#bayesloc_annotated_full.cfg includes a description of each parameter
#bayesloc_annotated_intermediate.cfg includes the parameters that you play with when you move past "short" input
#bayesloc_annotated_advanced.cfg includes parameter that advanced uses may use. Modify parameters not in bayesloc_annotated_advanced.cfg at your own risk.

# Best Regards
# Steve Myers, LLNL


